@@ -3,7 +3,7 @@ import anthropic
 client = anthropic.Anthropic()
 
 response = client.messages.create(
-    model="claude-3-7-sonnet-20250219",
+    model="claude-sonnet-4-5-20250929",
     max_tokens=3200,
     thinking={"type": "enabled", "budget_tokens": 1600},
     messages=[{"role": "user", "content": "Create a haiku about Anthropic."}],
