@@ -101,7 +101,9 @@ class BetaMessageStream:
                 text_blocks.append(block.text)
 
         if not text_blocks:
-            raise RuntimeError("Expected to have received at least 1 text block")
+            raise RuntimeError(
+                f".get_final_text() can only be called when the API returns a `text` content block.\nThe API returned {','.join([b.type for b in message.content])} content block type(s) that you can access by calling get_final_message().content"
+            )
 
         return "".join(text_blocks)
 
@@ -239,7 +241,9 @@ class BetaAsyncMessageStream:
                 text_blocks.append(block.text)
 
         if not text_blocks:
-            raise RuntimeError("Expected to have received at least 1 text block")
+            raise RuntimeError(
+                f".get_final_text() can only be called when the API returns a `text` content block.\nThe API returned {','.join([b.type for b in message.content])} content block type(s) that you can access by calling get_final_message().content"
+            )
 
         return "".join(text_blocks)
 
@@ -482,6 +486,7 @@ def accumulate_event(
         current_snapshot.stop_reason = event.delta.stop_reason
         current_snapshot.stop_sequence = event.delta.stop_sequence
         current_snapshot.usage.output_tokens = event.usage.output_tokens
+        current_snapshot.context_management = event.context_management
 
         # Update other usage fields if they exist in the event
         if event.usage.input_tokens is not None:
